@@ -17,38 +17,37 @@
 # along with Lightbulb. If not, see <https://www.gnu.org/licenses/>.
 import typing
 
-from lightbulb import utils
-from lightbulb import plugins
+from lightbulb import checks
+from lightbulb import command_handler
 from lightbulb import commands
+from lightbulb import context
 from lightbulb import converters
 from lightbulb import cooldowns
-from lightbulb import command_handler
-from lightbulb import checks
 from lightbulb import errors
-from lightbulb import context
 from lightbulb import help
+from lightbulb import plugins
 from lightbulb import stringview
-
-from lightbulb.plugins import *
+from lightbulb import utils
+from lightbulb.checks import *
+from lightbulb.command_handler import *
 from lightbulb.commands import *
 from lightbulb.context import *
 from lightbulb.converters import *
 from lightbulb.cooldowns import *
-from lightbulb.command_handler import *
-from lightbulb.checks import *
 from lightbulb.help import *
+from lightbulb.plugins import *
 from lightbulb.stringview import *
 
-__all__: typing.Final[typing.Tuple[str]] = (
-    plugins.__all__
-    + commands.__all__
-    + converters.__all__
-    + cooldowns.__all__
-    + command_handler.__all__
-    + checks.__all__
-    + context.__all__
-    + stringview.__all__
-    + help.__all__
-)
+__all__: typing.Final[typing.List[str]] = [
+    *plugins.__all__,
+    *commands.__all__,
+    *converters.__all__,
+    *cooldowns.__all__,
+    *command_handler.__all__,
+    *checks.__all__,
+    *context.__all__,
+    *stringview.__all__,
+    *help.__all__,
+]
 
-__version__ = "0.0.39"
+__version__ = "0.0.41"
