@@ -19,28 +19,23 @@ from __future__ import annotations
 
 __all__: typing.Final[typing.List[str]] = ["Bot"]
 
-import typing
-import functools
 import collections
-import inspect
-import sys
+import functools
 import importlib
+import inspect
 import logging
-from multidict import CIMultiDict
+import sys
+import typing
 
 import hikari
-from hikari.events import message_events as message
-from hikari.impl import stateful_cache
+from multidict import CIMultiDict
 
 from lightbulb import commands
 from lightbulb import context
 from lightbulb import errors
-from lightbulb import stringview
-from lightbulb import plugins
 from lightbulb import help as help_command
-
-if typing.TYPE_CHECKING:
-    from hikari.models import messages
+from lightbulb import plugins
+from lightbulb import stringview
 
 _LOGGER = logging.getLogger("lightbulb")
 
@@ -90,7 +85,7 @@ class Bot(hikari.Bot):
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
-        self.subscribe(message.MessageCreateEvent, self.handle)
+        self.subscribe(hikari.MessageCreateEvent, self.handle)
 
         if isinstance(prefix, str):
             self.get_prefix = functools.partial(_return_prefix, prefixes=[prefix])
@@ -110,16 +105,12 @@ class Bot(hikari.Bot):
         self._commands: typing.MutableMapping[
             str, commands.Command
         ] = dict() if not self.insensitive_commands else CIMultiDict()
-        self.commands: typing.Set(commands.Command) = set()
+        self.commands: typing.Set[commands.Command] = set()
         """A set containing all commands and groups registered to the bot."""
         self._checks = []
 
         self._help_impl = help_class(self)
 
-    @property
-    def _has_stateful_cache(self):
-        return isinstance(self.cache, stateful_cache.StatefulCacheImpl)
-
     async def fetch_owner_ids(self) -> None:
         """
         Fetches the IDs of the bot's owner(s) from the API and stores them in
@@ -559,12 +550,12 @@ class Bot(hikari.Bot):
                 unique_commands.extend(list(command.subcommands))
             yield command
 
-    def resolve_arguments(self, message: messages.Message, prefix: str) -> typing.List[str]:
+    def resolve_arguments(self, message: hikari.Message, prefix: str) -> typing.List[str]:
         """
         Resolves the arguments that a command was invoked with from the message containing the invocation.
 
         Args:
-            message (:obj:`hikari.models.messages.Message`): The message to resolve the arguments for.
+            message (:obj:`hikari.messages.Message`): The message to resolve the arguments for.
             prefix (:obj:`str`): The prefix the command was executed with.
 
         Returns:
@@ -634,7 +625,9 @@ class Bot(hikari.Bot):
                 else:
                     await command.invoke(context, *args[:before_asterisk])
         except errors.CommandError as ex:
-            error_event = errors.CommandErrorEvent(app=self, exception=ex, message=context.message, command=command)
+            error_event = errors.CommandErrorEvent(
+                app=self, exception=ex, context=context, message=context.message, command=command
+            )
 
             if command._error_listener is not None:
                 await command._error_listener(error_event)
@@ -656,7 +649,7 @@ class Bot(hikari.Bot):
 
         return new_args
 
-    async def handle(self, event: message.MessageCreateEvent) -> None:
+    async def handle(self, event: hikari.MessageCreateEvent) -> None:
         """
         The message listener that deals with validating the invocation messages. If invocation message
         is valid then it will invoke the relevant command.
