@@ -46,20 +46,20 @@ __all__: typing.Final[typing.List[str]] = [
 ]
 
 import abc
-import attr
 import typing
 
+import attr
 import hikari
-from hikari.events import base_events
 
 from lightbulb import commands
+from lightbulb import context as context_
 
 if typing.TYPE_CHECKING:
     import types
 
 
 @attr.s(kw_only=True, slots=True)
-class CommandErrorEvent(base_events.Event):
+class CommandErrorEvent(hikari.Event):
     """
     Event type to subscribe to for the processing of all command errors raised by the handler.
 
@@ -81,6 +81,8 @@ class CommandErrorEvent(base_events.Event):
     """App instance for this application."""
     exception: LightbulbError = attr.ib()
     """The exception that triggered this event."""
+    context: typing.Optional[context_.Context] = attr.ib(default=None)
+    """The context that this event was triggered for. Will be ``None`` for :obj:`~CommandNotFound` errors."""
     message: hikari.Message = attr.ib()
     """The message that this event was triggered for."""
     command: typing.Optional[commands.Command] = attr.ib(default=None)
