@@ -15,12 +15,14 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with Lightbulb. If not, see <https://www.gnu.org/licenses/>.
+from __future__ import annotations
+
+__all__: typing.Final[typing.List[str]] = ["StringView"]
+
 import typing
 
 from lightbulb import errors
 
-__all__: typing.Final[typing.Tuple[str]] = ("StringView",)
-
 _quotes = {
     '"': '"',
     "'": "'",
